achievement library

Classes

AchievementUnlockEntity
Individual user unlock entity for an achievement.
AchievementUnlocksAchievement
Target achievement details inside unlocks response.
AchievementUnlocksConsole
Console metadata in achievement unlocks response.
AchievementUnlocksGame
Game metadata in achievement unlocks response.
AchievementUnlocksMetadata
Complete metadata response returned by getAchievementUnlocks.

Enums

AchievementType
Achievement classification types on RetroAchievements.org.

Functions

getAchievementUnlocks(AuthObject authorization, {required int achievementId, int? offset, int? count, Client? client}) Future<AchievementUnlocksMetadata>
A call to this function will retrieve a list of users who have earned a given achievement, targeted by the achievement's ID.