auth library

Classes

AuthObject
Each RetroAchievements API call is uniquely authenticated using a username + API key combination. Your account's personal Web API Key can be found on the Settings page.

Functions

buildAuthorization({String? username, String? userName, required String webApiKey}) AuthObject
Accepts your RetroAchievements.org username and web API key. After receiving these inputs, the function returns an AuthObject that can be used for authentication by any of the API calls in this library.