cache library

Classes

RaCache
In-memory cache and fast lookup index for embedded RetroAchievements catalog data.

Functions

findCachedGameByHash(String hash, {int? consoleId}) GameListEntity?
Finds a cached game by its ROM MD5 hash.
findCachedGameById(int gameId, {int? consoleId}) GameListEntity?
Finds a cached game by its RetroAchievements game ID.
getCachedAllGames() List<GameListEntity>
Retrieves all cached games across all console systems.
getCachedConsoleIds({bool? shouldOnlyRetrieveActiveSystems, bool? shouldOnlyRetrieveGameSystems}) List<FetchedSystem>
Retrieves the complete list of RetroAchievements console systems from the embedded offline cache.
getCachedGameList({required int consoleId}) List<GameListEntity>
Retrieves the complete list of games for a specified console from the embedded offline cache.