comment library

Classes

CommentEntity
Single comment entity.
CommentsResponse
Response containing paginated comments.

Enums

CommentKind
What kind of identifier is targeted when retrieving comments.

Functions

getComments(AuthObject authorization, {required dynamic identifier, CommentKind? kind, int? offset, int? count, Client? client}) Future<CommentsResponse>
A call to this function will retrieve a list of comments on a particular target.

Typedefs

Comment = CommentEntity