feed library

Classes

AchievementOfTheWeek
Metadata about the current Achievement of the Week.
AchievementOfTheWeekAchievement
Achievement metadata for Achievement of the Week.
AchievementOfTheWeekConsole
Console metadata for Achievement of the Week.
AchievementOfTheWeekForumTopic
Forum topic metadata for Achievement of the Week.
AchievementOfTheWeekGame
Game metadata for Achievement of the Week.
AchievementOfTheWeekUnlock
Unlock entry for Achievement of the Week.
RecentGameAwardEntity
Single recent game award record.
RecentGameAwards
Metadata about all recently granted game awards across the site's userbase.
SetClaim
Metadata about a set claim.
TopTenUsersEntity
Single top ten user entry.

Enums

ClaimKind
Kind of claims to filter by in getClaims.
ClaimSetType
Whether the claim is for a new set or a revision.
ClaimStatus
Whether the claim is active, complete, or dropped.
ClaimType
Whether the claim is primary or a collaboration.

Functions

getAchievementOfTheWeek(AuthObject authorization, {Client? client}) Future<AchievementOfTheWeek>
A call to this function will retrieve comprehensive metadata about the current Achievement of the Week.
getActiveClaims(AuthObject authorization, {Client? client}) Future<List<SetClaim>>
A call to this function returns information about all (1000 max) active set claims.
getClaims(AuthObject authorization, {required ClaimKind claimKind, Client? client}) Future<List<SetClaim>>
A call to this function returns information about set claims of a specific kind (ClaimKind.completed, ClaimKind.dropped, or ClaimKind.expired).
getRecentGameAwards(AuthObject authorization, {String? startDate, int? offset, int? count, List<AwardKind>? desiredAwardKinds, Client? client}) Future<RecentGameAwards>
A call to this function will retrieve all recently granted game awards across the site's userbase.
getTopTenUsers(AuthObject authorization, {Client? client}) Future<TopTenUsers>
A call to this function will retrieve the current top ten users on the site.