game
library
Functions
-
getAchievementCount(AuthObject authorization, {required int gameId, Client? client})
→ Future<AchievementCount>
-
A call to this function will retrieve the list of
achievement IDs for a game, targeted by game ID.
-
getAchievementDistribution(AuthObject authorization, {required int gameId, AchievementDistributionFlags? flags, bool? hardcore, Client? client})
→ Future<Map<String, int>>
-
A call to this function will retrieve a dictionary
of the number of players who have earned a specific
number of achievements for a given game ID.
-
getGame(AuthObject authorization, {required int gameId, Client? client})
→ Future<Game>
-
A call to this function will retrieve basic metadata about
a game, targeted via its unique ID.
-
getGameExtended(AuthObject authorization, {required int gameId, bool? isRequestingUnofficialAchievements, Client? client})
→ Future<GameExtended>
-
A call to this function will retrieve extended metadata
about a game, targeted via its unique ID.
-
getGameHashes(AuthObject authorization, {required int gameId, Client? client})
→ Future<GameHashes>
-
A call to this function will retrieve a list of hashes linked to a game.
-
getGameProgression(AuthObject authorization, {required int gameId, bool? hardcore, Client? client})
→ Future<GameProgression>
-
A call to this function will retrieve information about the average time to unlock achievements in a game.
-
getGameRankAndScore(AuthObject authorization, {required int gameId, dynamic type, Client? client})
→ Future<List<GameRankAndScoreEntity>>
-
A call to this function will retrieve metadata about
either the latest masters for a game, or the highest
points earners for a game.
-
getGameRating(AuthObject authorization, {required int gameId, Client? client})
→ Future<GameRating>
-
A call to this function will retrieve metadata about
how users have rated the game and its set.