leaderboard library

Classes

GameLeaderboardEntity
Single game leaderboard entity.
GameLeaderboards
Metadata and list of leaderboards for a game.
LeaderboardEntries
Metadata and entries for a leaderboard.
LeaderboardEntry
Single entry on a leaderboard.
LeaderboardTopEntry
Top entry details for a leaderboard.
UserGameLeaderboardEntity
Single leaderboard with the target user's score entry.
UserGameLeaderboardEntry
User's entry on a leaderboard.
UserGameLeaderboards
Metadata and user's entries across leaderboards for a game.

Functions

getGameLeaderboards(AuthObject authorization, {required int gameId, int? offset, int? count, Client? client}) Future<GameLeaderboards>
A call to this function will retrieve a list of leaderboards for a given game ID.
getLeaderboardEntries(AuthObject authorization, {required int leaderboardId, int? offset, int? count, Client? client}) Future<LeaderboardEntries>
A call to this endpoint will retrieve a given leaderboard's entries, targeted by its ID.
getUserGameLeaderboards(AuthObject authorization, {required int gameId, required String username, int? offset, int? count, Client? client}) Future<UserGameLeaderboards>
A call to this endpoint will retrieve a user's list of leaderboards for a given game, targeted by the game's ID and the username.