AchievementCount class

Represents achievement IDs associated with a game.

Constructors

AchievementCount({required int gameId, required List<int> achievementIds})
const
AchievementCount.fromJson(Map<String, dynamic> json)
factory

Properties

achievementIds List<int>
List of achievement IDs for the game.
final
gameId int
Unique game ID.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override