AchievementOfTheWeekAchievement class

Achievement metadata for Achievement of the Week.

Constructors

AchievementOfTheWeekAchievement({required int id, required String title, required String description, required int points, required int trueRatio, required String author, required String dateCreated, required String dateModified, required String badgeName, required String badgeUrl})
const
AchievementOfTheWeekAchievement.fromJson(Map<String, dynamic> json)
factory

Properties

author String
final
badgeName String
final
badgeUrl String
final
dateCreated String
final
dateModified String
final
description String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
points int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
trueRatio int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override