AuthObject class

Each RetroAchievements API call is uniquely authenticated using a username + API key combination. Your account's personal Web API Key can be found on the Settings page.

Constructors

AuthObject({required String username, required String webApiKey})
const
AuthObject.buildAuthorization({String? username, String? userName, required String webApiKey})
Accepts your RetroAchievements.org username and web API key. After receiving these inputs, the function returns an AuthObject that can be used for authentication by any of the API calls in this library.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String
Backward-compatible alias for username.
no setter
username String
You or your app's exact username on the RetroAchievements.org website. For example, https://retroachievements.org/user/Scott would have a value of "Scott".
final
webApiKey String
This can be found in the "Keys" section of your Settings page on the RetroAchievements.org website. This is a 32-digit alphanumeric key that is case-sensitive.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override