DatedUserAchievement class

Achievement earned by a user on a specific date.

Constructors

DatedUserAchievement({required String date, required bool hardcoreMode, required int achievementId, required String title, required String description, required String badgeName, required int points, required String author, required String gameTitle, required String gameIcon, required int gameId, required String consoleName, required int cumulScore, required String badgeUrl, required String gameUrl, AchievementType? type})
const
DatedUserAchievement.fromJson(Map<String, dynamic> json)
factory

Properties

achievementId int
final
author String
final
badgeName String
final
badgeUrl String
final
consoleName String
final
cumulScore int
final
date String
final
description String
final
gameIcon String
final
gameId int
final
gameTitle String
final
gameUrl String
final
hardcoreMode bool
final
hashCode int
The hash code for this object.
no setteroverride
points int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
type AchievementType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override