FetchedSystem class

A console or gaming system supported on RetroAchievements.org.

Constructors

FetchedSystem({required int id, required String name, String? iconUrl, bool? active, bool? isGameSystem})
const
FetchedSystem.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
Indicates whether the system is active.
final
hashCode int
The hash code for this object.
no setteroverride
iconUrl String?
System icon URL on RetroAchievements.
final
id int
Unique identifier of the system.
final
isGameSystem bool?
Indicates whether the system represents a playable game system (vs events/hubs).
final
name String
Name of the system (e.g., "Mega Drive").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override