GameProgression class

Information about the average time to unlock achievements and beat/master a game.

Constructors

GameProgression({required int id, required String title, required int consoleId, required String consoleName, required String imageIcon, required int numDistinctPlayers, required int timesUsedInBeatMedian, required int timesUsedInHardcoreBeatMedian, int? medianTimeToBeat, int? medianTimeToBeatHardcore, required int timesUsedInCompletionMedian, required int timesUsedInMasteryMedian, int? medianTimeToComplete, int? medianTimeToMaster, required int numAchievements, required List<GameProgressionAchievement> achievements})
const
GameProgression.fromJson(Map<String, dynamic> json)
factory

Properties

achievements List<GameProgressionAchievement>
final
consoleId int
final
consoleName String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
imageIcon String
final
medianTimeToBeat int?
final
medianTimeToBeatHardcore int?
final
medianTimeToComplete int?
final
medianTimeToMaster int?
final
numAchievements int
final
numDistinctPlayers int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timesUsedInBeatMedian int
final
timesUsedInCompletionMedian int
final
timesUsedInHardcoreBeatMedian int
final
timesUsedInMasteryMedian int
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override