MostTicketedGames class

Response containing most ticketed games on RetroAchievements.

Constructors

MostTicketedGames({required List<ReportedGameEntity> mostReportedGames, required String url})
const
MostTicketedGames.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
mostReportedGames List<ReportedGameEntity>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override