UserAward class

Single visible award entity for a user.

Constructors

UserAward({required String awardedAt, AwardType? awardType, required int awardData, required int awardDataExtra, required int displayOrder, required String title, required String consoleName, int? flags, required String imageIcon})
const
UserAward.fromJson(Map<String, dynamic> json)
factory

Properties

awardData int
final
awardDataExtra int
final
awardedAt String
final
awardType AwardType?
final
consoleName String
final
displayOrder int
final
flags int?
final
hashCode int
The hash code for this object.
no setteroverride
imageIcon String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override