UserClaim class

Achievement set claim made by a user/developer.

Constructors

UserClaim({required int id, required String user, required int gameId, required String gameTitle, required String gameIcon, required String consoleName, required int claimType, required int setType, required int status, required int extension, required int special, required String created, required String doneTime, required String updated, required int minutesLeft})
const
UserClaim.fromJson(Map<String, dynamic> json)
factory

Properties

claimType int
final
consoleName String
final
created String
final
doneTime String
final
extension int
final
gameIcon String
final
gameId int
final
gameTitle String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
minutesLeft int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setType int
final
special int
final
status int
final
updated String
final
user String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override