UserCompletionProgressEntity class

Single item in a user's completion progress list.

Constructors

UserCompletionProgressEntity({required int gameId, required String title, required String imageIcon, required int consoleId, required String consoleName, required int maxPossible, required int numAwarded, required int numAwardedHardcore, String? mostRecentAwardedDate, AwardKind? highestAwardKind, String? highestAwardDate})
const
UserCompletionProgressEntity.fromJson(Map<String, dynamic> json)
factory

Properties

consoleId int
final
consoleName String
final
gameId int
final
hashCode int
The hash code for this object.
no setteroverride
highestAwardDate String?
final
highestAwardKind AwardKind?
final
imageIcon String
final
maxPossible int
final
mostRecentAwardedDate String?
final
numAwarded int
final
numAwardedHardcore int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override