UserRecentlyPlayedGameEntity class

Recently played game entry with user score and achievements.

Constructors

UserRecentlyPlayedGameEntity({required int gameId, required int consoleId, required String consoleName, required String title, required String imageIcon, required String lastPlayed, int? myVote, required int numPossibleAchievements, required int possibleScore, required int numAchieved, required int scoreAchieved, required int numAchievedHardcore, required int scoreAchievedHardcore})
const
UserRecentlyPlayedGameEntity.fromJson(Map<String, dynamic> json)
factory

Properties

consoleId int
final
consoleName String
final
gameId int
final
hashCode int
The hash code for this object.
no setteroverride
imageIcon String
final
lastPlayed String
final
myVote int?
final
numAchieved int
final
numAchievedHardcore int
final
numPossibleAchievements int
final
possibleScore int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoreAchieved int
final
scoreAchievedHardcore int
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override