ticket library

Classes

AchievementTicketStats
Ticket statistics for an achievement.
GameTicketStats
Ticket statistics for a game.
MostTicketedGames
Response containing most ticketed games on RetroAchievements.
RecentTickets
Response containing recent tickets.
ReportedGameEntity
Single reported game entry for most-ticketed games.
TicketEntity
Metadata for a single ticket entity.
UserTicketStats
Ticket statistics for a user/developer.

Functions

getAchievementTicketStats(AuthObject authorization, {required int achievementId, Client? client}) Future<AchievementTicketStats>
Helper function to retrieve an achievement's ticket stats.
getGameTicketStats(AuthObject authorization, {required int gameId, bool? isGettingTicketsForUnofficialAchievements, bool? shouldReturnTicketsList, Client? client}) Future<GameTicketStats>
Helper function to retrieve a game's ticket stats.
getMostTicketedGames(AuthObject authorization, {int? offset, int? count, Client? client}) Future<MostTicketedGames>
Helper function to retrieve games with highest count of opened tickets.
getRecentTickets(AuthObject authorization, {int? offset, int? count, Client? client}) Future<RecentTickets>
Helper function to retrieve latest opened achievement tickets.
getTicketById(AuthObject authorization, {required int ticketId, Client? client}) Future<TicketEntity>
Helper function to retrieve a single ticket by its ID.
getTicketData(AuthObject authorization, {int? ticketId, int? offset, int? count, bool? isGettingMostTicketedGames, String? username, int? gameId, bool? isGettingTicketsForUnofficialAchievements, bool? shouldReturnTicketsList, int? achievementId, Client? client}) Future
A call to this function will retrieve ticket metadata information depending on the arguments provided.
getUserTicketStats(AuthObject authorization, {required String username, Client? client}) Future<UserTicketStats>
Helper function to retrieve an achievement developer's ticket stats.