user library

Classes

AwardedGameEntity
Awarded game stats in user summary.
DatedUserAchievement
Achievement earned by a user on a specific date.
ExtendedRecentAchievementEntity
Extended recent achievement in user summary.
GameExtendedAchievementEntityWithUserProgress
Extended achievement details including user completion date.
GameInfoAndUserProgress
Metadata and user progress for a game.
LastActivityEntity
Last activity details in user summary.
LastGameEntity
Last played game metadata in user summary.
RecentlyPlayedGameEntity
Recently played game entry in user summary.
UserAward
Single visible award entity for a user.
UserAwards
Aggregated user award statistics and visible award badges.
UserClaim
Achievement set claim made by a user/developer.
UserCompletedGame
Game completed by a user.
UserCompletionProgress
Paginated completion progress response for a user.
UserCompletionProgressEntity
Single item in a user's completion progress list.
UserFollowerEntity
Follower entity in followers response.
UserFollowingEntity
User followed by the authenticated user.
UserGameRankAndScoreEntity
User rank and score entry for a game.
UserPoints
Point totals for a user.
UserProfile
Profile information for a user.
UserProgressEntity
Progress made by a user on a specific game.
UserRecentAchievement
Recent achievement earned by a user.
UserRecentlyPlayedGameEntity
Recently played game entry with user score and achievements.
UserSetRequestGame
Game item in a user's set requests.
UserSetRequests
Set requests made by a user.
UsersFollowingMe
Paginated list of users following the authenticated user.
UsersIFollow
Paginated list of users followed by the authenticated user.
UserSummary
Comprehensive summary profile and recent activity for a user.
UserWantToPlayItem
Single game item in a user's Want to Play list.
UserWantToPlayList
Paginated Want to Play list for a user.

Enums

AwardKind
Award classification kind.
AwardType
Award type descriptors.
RequestListType
Type of set requests list to retrieve.

Functions

getAchievementsEarnedBetween(AuthObject authorization, {required String username, required DateTime fromDate, required DateTime toDate, Client? client}) Future<List<DatedUserAchievement>>
A call to this function will retrieve a list of achievements earned by a given user between two provided dates.
getAchievementsEarnedOnDay(AuthObject authorization, {required String username, required DateTime onDate, Client? client}) Future<List<DatedUserAchievement>>
A call to this function will retrieve a list of achievements earned by a given user on a specified date.
getGameInfoAndUserProgress(AuthObject authorization, {required int gameId, required String username, bool? shouldIncludeHighestAwardMetadata, Client? client}) Future<GameInfoAndUserProgress>
A call to this function will retrieve extended metadata about a game, in addition to a user's progress for that game.
getUserAwards(AuthObject authorization, {required String username, Client? client}) Future<UserAwards>
A call to this function will retrieve metadata about the target user's site awards, via their username.
getUserClaims(AuthObject authorization, {required String username, Client? client}) Future<UserClaims>
A call to this function will retrieve a list of achievement set claims made over the lifetime of a given user, targeted by their username.
getUserCompletedGames(AuthObject authorization, {required String username, Client? client}) Future<UserCompletedGames>
A call to this function will retrieve completion metadata about the games a given user has played.
getUserCompletionProgress(AuthObject authorization, {required String username, int? offset, int? count, Client? client}) Future<UserCompletionProgress>
A call to this function will retrieve a given user's completion progress, targeted by their username.
getUserGameRankAndScore(AuthObject authorization, {required int gameId, required String username, Client? client}) Future<UserGameRankAndScore>
A call to this function will retrieve metadata about how a particular user has performed/ranked on a particular game, targeted by game ID.
getUserPoints(AuthObject authorization, {required String username, Client? client}) Future<UserPoints>
A call to this function will retrieve a given user's hardcore and softcore points.
getUserProfile(AuthObject authorization, {required String username, Client? client}) Future<UserProfile>
A call to this function will retrieve summary information about a given user, targeted by username.
getUserProgress(AuthObject authorization, {required String username, required List<int> gameIds, Client? client}) Future<UserProgress>
A call to this function will retrieve a given user's progress on a given list of games, targeted by game ID.
getUserRecentAchievements(AuthObject authorization, {required String username, int? recentMinutes, Client? client}) Future<List<UserRecentAchievement>>
A call to this function will retrieve a list of a target user's recently earned achievements, via their username.
getUserRecentlyPlayedGames(AuthObject authorization, {required String username, int? offset, int? count, Client? client}) Future<UserRecentlyPlayedGames>
A call to this function will retrieve a list of a target user's recently played games, via their username.
getUserSetRequests(AuthObject authorization, {required String username, RequestListType? requestListType, Client? client}) Future<UserSetRequests>
A call to this function will retrieve a given user's set requests.
getUsersFollowingMe(AuthObject authorization, {int? offset, int? count, Client? client}) Future<UsersFollowingMe>
A call to this function will retrieve the list of users that are following the caller.
getUsersIFollow(AuthObject authorization, {int? offset, int? count, Client? client}) Future<UsersIFollow>
A call to this function will retrieve the list of users that the caller is following.
getUserSummary(AuthObject authorization, {required String username, int? recentGamesCount, int? recentAchievementsCount, Client? client}) Future<UserSummary>
A call to this function will retrieve summary information about a given user, targeted by username.
getUserWantToPlayList(AuthObject authorization, {required String username, int? offset, int? count, Client? client}) Future<UserWantToPlayList>
A call to this function will retrieve a user's "Want to Play Games" list.

Typedefs

UserClaims = List<UserClaim>
Type alias for list of user claims.
UserCompletedGames = List<UserCompletedGame>
Type alias for list of completed games.
UserGameRankAndScore = List<UserGameRankAndScoreEntity>
Type alias for list of user game rank and scores.
UserProgress = Map<int, UserProgressEntity>
Map of game IDs to user progress entities.
UserRecentlyPlayedGames = List<UserRecentlyPlayedGameEntity>
Type alias for list of recently played games.