console
library
Classes
-
FetchedSystem
-
A console or gaming system supported on RetroAchievements.org.
-
GameListEntity
-
Metadata entity for a game within a console's game list.
Functions
-
getConsoleIds(AuthObject authorization, {bool? shouldOnlyRetrieveActiveSystems, bool? shouldOnlyRetrieveGameSystems, Client? client})
→ Future<List<FetchedSystem>>
-
A call to this function will retrieve the complete list
of console ID and name pairs on the RetroAchievements.org
platform.
-
getGameList(AuthObject authorization, {required int consoleId, bool shouldOnlyRetrieveGamesWithAchievements = true, bool shouldRetrieveGameHashes = true, Client? client})
→ Future<GameList>
-
A call to this function will retrieve the complete list
of games for a specified console on the RetroAchievements.org
platform.