feed
library
Functions
-
getAchievementOfTheWeek(AuthObject authorization, {Client? client})
→ Future<AchievementOfTheWeek>
-
A call to this function will retrieve comprehensive
metadata about the current Achievement of the Week.
-
getActiveClaims(AuthObject authorization, {Client? client})
→ Future<List<SetClaim>>
-
A call to this function returns information about all (1000 max) active set claims.
-
getClaims(AuthObject authorization, {required ClaimKind claimKind, Client? client})
→ Future<List<SetClaim>>
-
A call to this function returns information about set claims of a specific kind
(ClaimKind.completed, ClaimKind.dropped, or ClaimKind.expired).
-
getRecentGameAwards(AuthObject authorization, {String? startDate, int? offset, int? count, List<AwardKind>? desiredAwardKinds, Client? client})
→ Future<RecentGameAwards>
-
A call to this function will retrieve all recently granted game
awards across the site's userbase.
-
getTopTenUsers(AuthObject authorization, {Client? client})
→ Future<TopTenUsers>
-
A call to this function will retrieve the current top ten users on the site.