game library

Classes

AchievementCount
Represents achievement IDs associated with a game.
Game
Metadata for a game on RetroAchievements.
GameExtended
Extended metadata and achievement map for a game.
GameExtendedAchievementEntity
Extended achievement details within a game's extended metadata.
GameExtendedClaimEntity
Set claim metadata for a game.
GameHash
A hash entry linked to a game ROM.
GameHashes
List of hashes associated with a game.
GameProgression
Information about the average time to unlock achievements and beat/master a game.
GameProgressionAchievement
Achievement unlock time stats in game progression.
GameRankAndScoreEntity
A high-score or mastery entry for a game.
GameRating
Ratings metadata for a game.
GameRatingDetails
Rating details breakdown for a game and its achievements.

Enums

AchievementDistributionFlags
Filter flags for fetching achievement distributions.
GameRankAndScoreType
Type of ranking to retrieve for a game.

Functions

getAchievementCount(AuthObject authorization, {required int gameId, Client? client}) Future<AchievementCount>
A call to this function will retrieve the list of achievement IDs for a game, targeted by game ID.
getAchievementDistribution(AuthObject authorization, {required int gameId, AchievementDistributionFlags? flags, bool? hardcore, Client? client}) Future<Map<String, int>>
A call to this function will retrieve a dictionary of the number of players who have earned a specific number of achievements for a given game ID.
getGame(AuthObject authorization, {required int gameId, Client? client}) Future<Game>
A call to this function will retrieve basic metadata about a game, targeted via its unique ID.
getGameExtended(AuthObject authorization, {required int gameId, bool? isRequestingUnofficialAchievements, Client? client}) Future<GameExtended>
A call to this function will retrieve extended metadata about a game, targeted via its unique ID.
getGameHashes(AuthObject authorization, {required int gameId, Client? client}) Future<GameHashes>
A call to this function will retrieve a list of hashes linked to a game.
getGameProgression(AuthObject authorization, {required int gameId, bool? hardcore, Client? client}) Future<GameProgression>
A call to this function will retrieve information about the average time to unlock achievements in a game.
getGameRankAndScore(AuthObject authorization, {required int gameId, dynamic type, Client? client}) Future<List<GameRankAndScoreEntity>>
A call to this function will retrieve metadata about either the latest masters for a game, or the highest points earners for a game.
getGameRating(AuthObject authorization, {required int gameId, Client? client}) Future<GameRating>
A call to this function will retrieve metadata about how users have rated the game and its set.