leaderboard
library
Functions
-
getGameLeaderboards(AuthObject authorization, {required int gameId, int? offset, int? count, Client? client})
→ Future<GameLeaderboards>
-
A call to this function will retrieve a list of leaderboards for a given game ID.
-
getLeaderboardEntries(AuthObject authorization, {required int leaderboardId, int? offset, int? count, Client? client})
→ Future<LeaderboardEntries>
-
A call to this endpoint will retrieve a given leaderboard's entries, targeted by its ID.
-
getUserGameLeaderboards(AuthObject authorization, {required int gameId, required String username, int? offset, int? count, Client? client})
→ Future<UserGameLeaderboards>
-
A call to this endpoint will retrieve a user's list of leaderboards for a given game,
targeted by the game's ID and the username.