user
library
Functions
-
getAchievementsEarnedBetween(AuthObject authorization, {required String username, required DateTime fromDate, required DateTime toDate, Client? client})
→ Future<List<DatedUserAchievement>>
-
A call to this function will retrieve a list of achievements
earned by a given user between two provided dates.
-
getAchievementsEarnedOnDay(AuthObject authorization, {required String username, required DateTime onDate, Client? client})
→ Future<List<DatedUserAchievement>>
-
A call to this function will retrieve a list of achievements
earned by a given user on a specified date.
-
getGameInfoAndUserProgress(AuthObject authorization, {required int gameId, required String username, bool? shouldIncludeHighestAwardMetadata, Client? client})
→ Future<GameInfoAndUserProgress>
-
A call to this function will retrieve extended metadata
about a game, in addition to a user's progress for that game.
-
getUserAwards(AuthObject authorization, {required String username, Client? client})
→ Future<UserAwards>
-
A call to this function will retrieve metadata about the target user's
site awards, via their username.
-
getUserClaims(AuthObject authorization, {required String username, Client? client})
→ Future<UserClaims>
-
A call to this function will retrieve a list of
achievement set claims made over the lifetime of a given
user, targeted by their username.
-
getUserCompletedGames(AuthObject authorization, {required String username, Client? client})
→ Future<UserCompletedGames>
-
A call to this function will retrieve completion metadata
about the games a given user has played.
-
getUserCompletionProgress(AuthObject authorization, {required String username, int? offset, int? count, Client? client})
→ Future<UserCompletionProgress>
-
A call to this function will retrieve a given user's completion
progress, targeted by their username.
-
getUserGameRankAndScore(AuthObject authorization, {required int gameId, required String username, Client? client})
→ Future<UserGameRankAndScore>
-
A call to this function will retrieve metadata about
how a particular user has performed/ranked on a particular
game, targeted by game ID.
-
getUserPoints(AuthObject authorization, {required String username, Client? client})
→ Future<UserPoints>
-
A call to this function will retrieve a given user's hardcore
and softcore points.
-
getUserProfile(AuthObject authorization, {required String username, Client? client})
→ Future<UserProfile>
-
A call to this function will retrieve summary information about
a given user, targeted by username.
-
getUserProgress(AuthObject authorization, {required String username, required List<int> gameIds, Client? client})
→ Future<UserProgress>
-
A call to this function will retrieve a given user's
progress on a given list of games, targeted by game ID.
-
getUserRecentAchievements(AuthObject authorization, {required String username, int? recentMinutes, Client? client})
→ Future<List<UserRecentAchievement>>
-
A call to this function will retrieve a list of a target user's
recently earned achievements, via their username.
-
getUserRecentlyPlayedGames(AuthObject authorization, {required String username, int? offset, int? count, Client? client})
→ Future<UserRecentlyPlayedGames>
-
A call to this function will retrieve a list of a target user's
recently played games, via their username.
-
getUserSetRequests(AuthObject authorization, {required String username, RequestListType? requestListType, Client? client})
→ Future<UserSetRequests>
-
A call to this function will retrieve a given user's set requests.
-
getUsersFollowingMe(AuthObject authorization, {int? offset, int? count, Client? client})
→ Future<UsersFollowingMe>
-
A call to this function will retrieve the list of users that are
following the caller.
-
getUsersIFollow(AuthObject authorization, {int? offset, int? count, Client? client})
→ Future<UsersIFollow>
-
A call to this function will retrieve the list of users that the
caller is following.
-
getUserSummary(AuthObject authorization, {required String username, int? recentGamesCount, int? recentAchievementsCount, Client? client})
→ Future<UserSummary>
-
A call to this function will retrieve summary information about
a given user, targeted by username.
-
getUserWantToPlayList(AuthObject authorization, {required String username, int? offset, int? count, Client? client})
→ Future<UserWantToPlayList>
-
A call to this function will retrieve a user's "Want to Play Games" list.